/* 
 * PVM++ - A C++ library for easy use of PVM
 * Copyright (C) 1997-2001 Sebastian Wilhelmi; University of Karlsruhe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __PVM_HOST_HH__
#define __PVM_HOST_HH__

#include <pvm++/types.hh>

#include <string>

/** Class representing a host in the PVM.

    This class represents a host, that is part of the PVM. Internally
    it just stores a pointer to a data structure, so it is save and
    fast to use it as a value parameter and as a function result as
    well. Requests to the PVM, like Name() are cached, so you
    don't need to cache yourself.

    There is an ostream& operator<<( ostream& Stream, PvmHost What )
    defined as well. It outputs the host id as used by the PVM
    prepended by a "h".  */

class PvmHost
{
public:
  PvmHost ();
  PvmHost (const PvmHost &What);
  /** constructs a PvmHost for the host with the host id What as
      used by PVM. */
  PvmHost (unsigned int What);

  /** returns the host id as used by PVM. */
  operator unsigned int () const;

  /** returns the name of the host. */
  string Name () const;

  /** returns the name of the architecture of this host. */
  string Arch () const;

  /** returns the speed of this host. It's the same as in PVM. */
  unsigned int Speed () const;

  /** returns, whether the host is up and running and still part of
      the PVM. */
  bool Running () const;

  /** starts Num instances of the task with name Task on the current
      host and returns the set of started tasks in Result. The PVM
      rules regarding the default search path apply. */
  void Spawn (const string &Task, int Num, PvmTaskSet &Result) const;

  /** starts the task with name Task on the host and returns the
      corresponding instance of PvmTask.*/
  PvmTask Spawn (const string &Task) const;

  /** returns a list of all tasks, currently running on this host, in
      the reference parameter Result. */
  void Tasks (PvmTaskSet &Result) const;
private:
  PvmHostEntry *Where;
  PvmHostEntry *Get (unsigned int Id);
};

#endif /* __PVM_HOST_HH__ */
